@@ -7,7 +7,7 @@
 
  * Author: Ralph Amissah
 
- * Copyright: (C) 1997 - 2010, Ralph Amissah, All Rights Reserved.
+ * Copyright: (C) 1997 - 2011, Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -139,7 +139,6 @@ module SiSU_Manpage
           if wrap =~ /^\s*[\d*+]+\s+.+?\s*\Z/m
             wrap.gsub!(/(^|&nbsp;|#{Mx[:nbsp]}|\s|\*)\\\*/,'\1\\\\\*') #man page requires
             wrap.gsub!(/\s\.(\S+)/,' \\.\1')
-            wrap.gsub!(/(["''])/,"\\\\\\1")                                     # quotation marks need escape
             wrap.gsub!(/^\s*([\d*+]+)\s+(.+?)\s*\Z/m, <<GSUB
 .TP
 .BI \\1.
@@ -153,7 +152,7 @@ GSUB
                       )
           end
           @@endnotes[:para] << wrap
-          @@endnotes[:end] << wrap << "\n.BR"
+          @@endnotes[:end] << wrap << "\n.br"
           @@endnotes
         end
       end
@@ -177,16 +176,6 @@ Other versions of this document:
 .TP
 manifest: <#{vz.url_root_http}/#{@md.fnb}/#{@md.fn[:manifest]}>
 .TP
-html: <#{vz.url_root_http}/#{@md.fnb}/#{@md.fn[:toc]}>
-.TP
-epub: <#{vz.url_root_http}/epub/#{@md.fnb}.epub>
-.TP
-pdf: <#{vz.url_root_http}/#{@md.fnb}/#{@md.fn[:pdf_p]}>
-.TP
-pdf: <#{vz.url_root_http}/#{@md.fnb}/#{@md.fn[:pdf_l]}>
-.\" .TP
-.\" manpage: #{vz.url_root_http}/#{@md.fnb}/#{@md.fn[:manpage]}
-.TP
 at: <#{vz.url_site}>
 .TP
 #{sc}
@@ -232,16 +221,16 @@ WOK
           times=wrapped.length
           times=78 if times > 78
           @manpage[:body] << case lv
-          when 1;    '.SH ' << @br <<  wrapped.upcase << @br << '.BR'
-          when 2..3; '.SH ' << @br <<  wrapped.upcase << @br << '.BR'
-          when 4;    '.SH ' << @br <<  wrapped.upcase << @br << '.BR'
-          when 5..6; '.SH ' << @br <<  wrapped.upcase << @br
+          when 1;    '.SH ' << wrapped.upcase << @br << '.br'
+          when 2..3; '.SH ' << wrapped.upcase << @br << '.br'
+          when 4;    '.SH ' << wrapped.upcase << @br << '.br'
+          when 5..6; '.SH ' << wrapped.upcase << @br
           end
         else
           @manpage[:body] << if  wrapped =~/^\.BI\s/ # main text, contents, body KEEP
             '.TP' << @br << wrapped.gsub!(/^\.BI\s/,'.B ') # sleight ... simpler output
           else
-            '.BR' << @br << wrapped
+            '.br' << @br << wrapped
           end
         end
         if @@endnotes[:para] \
@@ -301,20 +290,20 @@ WOK
             dob.obj.gsub!(/(?:#{Mx[:br_line]}|#{Mx[:br_nl]})+\s*/,"\n")                                   # watch
           end
           dob.obj.gsub!(/(^|&nbsp;|#{Mx[:nbsp]}|\s|\*)\\\*/,'\1\\\\\*') #man page requires
+          dob.obj.gsub!(/┆/,'|')
           dob.obj.gsub!(/\s\.(\S+)/,' \\.\1')
           dob.obj.gsub!(/(\n\.)(\S\S\S+)/m,'\1\\.\2')
-          dob.obj.gsub!(/-/,'\-') #manpages use this
           dob.obj.gsub!(/&#126;/,'~') if dob.obj #manpages use this
           if dob.is =~/group|verse|alt|code/
             if dob.is =='code'
               dob.obj.gsub!(/(^|[^}])_([<>])/m,'\1\2') # _> _<
               dob.obj.gsub!(/(^|[^}])_([<>])/m,'\1\2') # _<_<
-              dob.obj.gsub!(/\A(.+)?\Z/m,"\n\n.nf\n\n\\1\n\n.fi\n\n") #dob.obj.gsub!(/\A/,"\n\n.nf\n\n"); #dob.obj.gsub!(/\Z/,"\n\n.fi\n\n") #bug, .fi repeats
+              dob.obj.gsub!(/\A(.+)?\Z/m,".nf\n\n\\1\n\n.fi")
             end
           else
             dob.obj.gsub!(/(?:#{Mx[:br_line]}|#{Mx[:br_nl]})\s*/,"\n\n") #unless para =~/#{Mx[:lv_o]}\d:/                                   #watch introduces a bug
           end
-          dob.obj.gsub!(/(?:#{Mx[:br_line]}|#{Mx[:br_nl]})+\s*/,"\n\n.BR\n\n")                                   # watch
+          dob.obj.gsub!(/(?:#{Mx[:br_line]}|#{Mx[:br_nl]})+\s*/,"\n\n.br\n\n")                                   # watch
           blit=dob.obj.scan(/\[[^\]]+\]|[^\[]+/)
           blit_array=[]
           blit.each do |x|
